@@ -741,3 +741,19 @@ terms( fitwlsi4$eq[[ 2 ]] )
 
 terms( fitwlsi5e )
 terms( fitwlsi5e$eq[[ 1 ]] )
+
+
+## **************** estfun ************************
+library( "sandwich" )
+
+estfun( fitwls1 )
+colSums( estfun( fitwls1 ) )
+
+estfun( fitwlsi1e )
+colSums( estfun( fitwlsi1e ) )
+
+
+## **************** bread ************************
+bread( fitwls1 )
+
+bread( fitwlsi1e )
